package VMOMI::HostVirtualNicManagerNicType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
